@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-29 09:40:42
-:LastEditTime: 2022-02-17 11:31:22
-:LastEditors: HuangJingCan
+@LastEditTime: 2022-02-23 11:08:24
+@LastEditors: ChenCheng
 :description: 机台（盒子）
 """
 import decimal
@@ -280,7 +280,7 @@ class MachineListHandler(ClientBaseHandler):
                     item["start_date"] = ""
                 if item["end_date"] == "1900-01-01 00:00:00":
                     item["end_date"] = ""
-                item["online_url"] = self.get_online_url(act_id, app_id) + "," + str(item["id"])
+                item["online_url"] = self.get_online_url(act_id, app_id) + "," + str(item["ip_id"]) + "," + str(item["id"])
 
         page_info = PageInfo(page_index, page_size, total, page_dict_list)
 
